@@ -12,10 +12,9 @@ are PROTECTed, and UNPROTECTing them in the
 case of a FORTRAN stop.
 ==================================================*/
  
-long int N_Protected = 0; //initialize this with zero at the first time
-
-int solver_locked = 0; /* prevent nested calls of odepack solvers */
+long int N_Protected = 0; /* initialize this with zero at the first time */
 
+int solver_locked = 0;   /* prevent nested calls of odepack solvers */
 
 void init_N_Protect(void) { N_Protected = 0; }
 
@@ -48,7 +47,11 @@ void lock_solver(void) {
   solver_locked = 1;
 }
 
-void unlock_solver(void) {solver_locked = 0;}
+void unlock_solver(void) {
+  solver_locked = 0;
+  timesteps[0] = 0;
+  timesteps[1] = 0;
+}
 
 
 /* Globals :*/
